package org.eclipse.html.editor;

import java.util.HashMap;

/**
 * Stores completions on attributes inside HTML tags.
 */
class AttributeCompletion extends HTMLCompletion {
   static {
      completions = new HashMap();
      generateCompletions(
         new String[][] {
            new String[] { "a", "name", "href" },
            new String[] { "body", "font", "bgcolor" },
            new String[] { "ol", "type" },
            });
   }
   private static final HashMap completions;
   /**
    * Returns all possible attributes for the given HTML tag.
    * Returns null if there are no known attributes for the tag.
    */
   public static AttributeCompletion[] attributesFor(String tag) {
      return (AttributeCompletion[]) completions.get(tag);
   }
   private static void generateCompletions(String[][] values) {
      for (int i = 0; i < values.length; i++) {
         String tag = values[i][0];
         AttributeCompletion[] result = new AttributeCompletion[values[i].length - 1];
         for (int j = 1; j < values[i].length; j++)
            result[j - 1] = new AttributeCompletion(values[i][j]);
         completions.put(tag, result);
      }
   }
   private static String generateReplaceText(String attribute) {
      StringBuffer buf = new StringBuffer(attribute.length() + 3);
      buf.append(attribute);
      buf.append("=\"");
      buf.append('"');
      return buf.toString();
   }
   private AttributeCompletion(String attribute) {
      super(attribute, "", generateReplaceText(attribute), attribute.length()+2);
   }
}