package org.eclipse.html.editor;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.jface.text.IDocument;
import org.eclipse.jface.text.IDocumentPartitioner;
import org.eclipse.jface.text.rules.*;
import org.eclipse.ui.editors.text.FileDocumentProvider;

public class HTMLDocumentProvider extends FileDocumentProvider {
   protected IDocument createDocument(Object element) throws CoreException {
      IDocument document = super.createDocument(element);
      if (document != null) {
         IDocumentPartitioner partitioner =
            new DefaultPartitioner(
               createScanner(),
               new String[] {
                  HTMLConfiguration.HTML_TAG,
                  HTMLConfiguration.HTML_COMMENT });
         partitioner.connect(document);
         document.setDocumentPartitioner(partitioner);
      }
      return document;
   }
   IPartitionTokenScanner createScanner() {
      IToken comment = new Token(HTMLConfiguration.HTML_COMMENT);
      IToken tag = new Token(HTMLConfiguration.HTML_TAG);
      IPredicateRule[] rules = new IPredicateRule[2];
      rules[0] = new MultiLineRule("<!--", "-->", comment);
      rules[1] = new TagRule(tag);
      RuleBasedPartitionScanner scanner = new RuleBasedPartitionScanner();
      scanner.setPredicateRules(rules);
      return scanner;
   }
}