package org.eclipse.html.editor;

import org.eclipse.core.resources.IMarker;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.*;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.ui.*;
import org.eclipse.ui.part.EditorPart;

/**
 * Simple editor example for the FAQs in the generic editors chapter.
 * This editor has non-text based contents, and illustrates the editor
 * dirty lifecycle with some example actions.
 */
public class MinimalEditor extends EditorPart {
   private Label contents;
   protected boolean dirty = false;
   private IAction dirtyAction = new Action("Dirty contents") {
      public void run() {
         setDirty(true);
      }
   };
   private IAction revertAction = new Action("Revert") {
      public void run() {
         setDirty(false);
      }
   };
   public void createPartControl(Composite parent) {
      contents = new Label(parent, SWT.NONE);
      contents.setText("Minimal Editor");
      MenuManager manager = new MenuManager();
      manager.add(dirtyAction);
      contents.setMenu(manager.createContextMenu(contents));
      getEditorSite().getActionBars().setGlobalActionHandler(
         IWorkbenchActionConstants.REVERT,
         revertAction);
   }
   public void doSave(IProgressMonitor monitor) {
      setDirty(false);
   }
   public void doSaveAs() {
      doSave(null);
   }
   public void gotoMarker(IMarker marker) {
   }
   public void init(IEditorSite site, IEditorInput input)
      throws PartInitException {
      setSite(site);
      setInput(input);
   }
   public boolean isDirty() {
      return dirty;
   }
   public boolean isSaveAsAllowed() {
      return false;
   }
   protected void setDirty(boolean value) {
      dirty = value;
      revertAction.setEnabled(dirty);
      firePropertyChange(PROP_DIRTY);
   }
   public void setFocus() {
      if (contents != null)
         contents.setFocus();
   }
}